@@ -1,13 +1,10 @@
-from typing import Optional
-
 from sqlmodel import Field, SQLModel
 
 from lightning_hpo.utilities.enum import Stage
 
 
 class TensorboardConfig(SQLModel, table=True):
-    id: Optional[int] = Field(default=None, primary_key=True)
-    sweep_id: str
+    sweep_id: str = Field(primary_key=True)
     shared_folder: str
     stage: str = Stage.NOT_STARTED
     desired_stage: str = Stage.RUNNING
